@@ -34,9 +34,10 @@
 #ifndef GETTEXTIMPORTPLUGIN_H
 #define GETTEXTIMPORTPLUGIN_H
 
+#include "lokalize_debug.h"
+
 #include "catalogfileplugin.h"
 
-#include <QDebug>
 #include <QStringList>
 #include <QTextStream>
 
