@@ -20,6 +20,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "gettextstorage.h"
 
+#include "lokalize_debug.h"
+
 #include "gettextheader.h"
 #include "catalogitem_private.h"
 #include "gettextimport.h"
@@ -37,7 +39,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QProcess>
 #include <QString>
 #include <QMap>
-#include <QDebug>
 
 #include <klocalizedstring.h>
 
@@ -257,7 +258,7 @@ QVector<AltTrans> GettextStorage::altTrans(const DocPosition& pos) const
 
 Note GettextStorage::setNote(DocPosition pos, const Note& note)
 {
-    //qWarning()<<"s"<<m_entries.at(pos.entry).comment();
+    //qCWarning(LOKALIZE_LOG)<<"s"<<m_entries.at(pos.entry).comment();
     Note oldNote;
     QVector<Note> l=notes(pos);
     if (l.size()) oldNote=l.first();
@@ -276,7 +277,7 @@ Note GettextStorage::setNote(DocPosition pos, const Note& note)
         comment.prepend(QStringLiteral("# ")+note.content.split('\n').join(QStringLiteral("\n# ")));
     m_entries[pos.entry].setComment(comment.join(QStringLiteral("\n")));
 
-    //qWarning()<<"e"<<m_entries.at(pos.entry).comment();
+    //qCWarning(LOKALIZE_LOG)<<"e"<<m_entries.at(pos.entry).comment();
     return oldNote;
 }
 
@@ -415,7 +416,7 @@ bool GettextStorage::setHeader(const CatalogItem& newHeader)
       // normalize the values - ensure every key:value pair is only on a single line
       QString values = newHeader.msgstr();
       values.replace (QStringLiteral("\\n"), QStringLiteral("\\n\n"));
-//       qDebug () << "Normalized header: " << values;
+//       qCDebug(LOKALIZE_LOG) << "Normalized header: " << values;
       QString comment=newHeader.comment();
       QString catalogProjectId;//=m_url.fileName(); FIXME m_url is always empty
       //catalogProjectId=catalogProjectId.left(catalogProjectId.lastIndexOf('.'));
@@ -439,7 +440,7 @@ bool GettextStorage::setHeader(const CatalogItem& newHeader)
 
       return true;
    }
-   qWarning () << "header Not valid";
+   qCWarning(LOKALIZE_LOG) << "header Not valid";
    return false;
 }
 
