@@ -21,13 +21,13 @@
 
 **************************************************************************** */
 
+#include "lokalize_debug.h"
+
 #include "tbxparser.h"
 
 #include "glossary.h"
 #include "project.h"
 
-#include <QDebug>
-
 using namespace GlossaryNS;
 
 bool TbxParser::startDocument()
