@@ -1,6 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
+  Copyright (C) 2018 by Karl Ove Hufthammer <karl@huftis.org>
   Copyright (C) 2007-2015 by Nick Shaforostoff <shafff@ukr.net>
   Copyright (C) 2009 by Viesturs Zarins <viesturs.zarins@mii.lu.lv>
 
@@ -23,12 +24,13 @@
 **************************************************************************** */
 
 #include "projectmodel.h"
+
+#include "lokalize_debug.h"
+
 #include "project.h"
 #include "poextractor.h"
 #include "xliffextractor.h"
 
-#include "kdemacros.h"
-
 #include <QIcon>
 #include <QTime>
 #include <QFile>
@@ -43,7 +45,6 @@
 
 #include <klocalizedstring.h>
 
-#undef KDE_NO_DEBUG_OUTPUT
 static int nodeCounter=0;
 
 //TODO: figure out how to handle file and folder renames...
@@ -111,7 +112,7 @@ ProjectModel::~ProjectModel()
 
 void ProjectModel::setUrl(const QUrl &poUrl, const QUrl &potUrl)
 {
-    //qDebug() << "ProjectModel::openUrl("<< poUrl.pathOrUrl() << +", " << potUrl.pathOrUrl() << ")";
+    //qCDebug(LOKALIZE_LOG) << "ProjectModel::openUrl("<< poUrl.pathOrUrl() << +", " << potUrl.pathOrUrl() << ")";
 
     emit loadingAboutToStart();
 
@@ -392,7 +393,7 @@ void ProjectModel::po_rowsRemoved(const QModelIndex& po_parent, int start, int e
 
     if ((!parent.isValid()) && (node->rows.count() == 0))
     {
-        qDebug()<<"po_rowsRemoved fail";
+        qCDebug(LOKALIZE_LOG)<<"po_rowsRemoved fail";
         //events after removing entire contents
         return;
     }
@@ -556,6 +557,7 @@ QVariant ProjectModel::headerData(int section, Qt::Orientation, int role) const
                 case TranslatedCount:   return QVariant(Qt::AlignRight | Qt::AlignAbsolute);
                 case FuzzyCount:        return QVariant(Qt::AlignRight | Qt::AlignAbsolute);
                 case UntranslatedCount: return QVariant(Qt::AlignRight | Qt::AlignAbsolute);
+                case IncompleteCount:   return QVariant(Qt::AlignRight | Qt::AlignAbsolute);
                 default:                return QVariant(Qt::AlignLeft);
             }
         }
@@ -569,6 +571,7 @@ QVariant ProjectModel::headerData(int section, Qt::Orientation, int role) const
                 case TranslatedCount:   return i18nc("@title:column Number of entries","Translated");
                 case FuzzyCount:        return i18nc("@title:column Number of entries","Not ready");
                 case UntranslatedCount: return i18nc("@title:column Number of entries","Untranslated");
+                case IncompleteCount:   return i18nc("@title:column Number of fuzzy or untranslated entries","Incomplete");
                 case TranslationDate:   return i18nc("@title:column","Last Translation");
                 case SourceDate:        return i18nc("@title:column","Template Revision");
                 case LastTranslator:    return i18nc("@title:column","Last Translator");
@@ -684,6 +687,7 @@ QVariant ProjectModel::data(const QModelIndex& index, int role) const
             case TranslatedCount:return hasStats?translated:QVariant();
             case FuzzyCount:    return hasStats?fuzzy:QVariant();
             case UntranslatedCount:return hasStats?untranslated:QVariant();
+            case IncompleteCount:return hasStats?(untranslated + fuzzy):QVariant();
             case SourceDate:    return node->sourceDate;
             case TranslationDate:return node->translationDate;
             case LastTranslator:return node->lastTranslator;
@@ -733,10 +737,10 @@ QVariant ProjectModel::data(const QModelIndex& index, int role) const
 QModelIndex ProjectModel::index(int row, int column, const QModelIndex& parent) const
 {
     ProjectNode* parentNode = nodeForIndex(parent);
-    //qWarning()<<(sizeof(ProjectNode))<<nodeCounter;
+    //qCWarning(LOKALIZE_LOG)<<(sizeof(ProjectNode))<<nodeCounter;
     if (row>=parentNode->rows.size())
     {
-        qWarning()<<"SHIT HAPPENED WITH INDEXES"<<row<<parentNode->rows.size()<<itemForIndex(parent).url();
+        qCWarning(LOKALIZE_LOG)<<"Issues with indexes"<<row<<parentNode->rows.size()<<itemForIndex(parent).url();
         return QModelIndex();
     }
     return createIndex(row, column, parentNode->rows.at(row));
@@ -762,12 +766,12 @@ KFileItem ProjectModel::itemForIndex(const QModelIndex& index) const
             return m_potModel.itemForIndex(potIndex);
     }
 
-    qWarning()<<"returning empty KFileItem()"<<index.row()<<index.column();
-    qWarning()<<"returning empty KFileItem()"<<index.parent().isValid();
-    qWarning()<<"returning empty KFileItem()"<<index.parent().internalPointer();
-    qWarning()<<"returning empty KFileItem()"<<index.parent().data().toString();
-    qWarning()<<"returning empty KFileItem()"<<index.internalPointer();
-    qWarning()<<"returning empty KFileItem()"<<static_cast<ProjectNode*>(index.internalPointer())->untranslated<<static_cast<ProjectNode*>(index.internalPointer())->sourceDate;
+    qCInfo(LOKALIZE_LOG)<<"returning empty KFileItem()"<<index.row()<<index.column();
+    qCInfo(LOKALIZE_LOG)<<"returning empty KFileItem()"<<index.parent().isValid();
+    qCInfo(LOKALIZE_LOG)<<"returning empty KFileItem()"<<index.parent().internalPointer();
+    qCInfo(LOKALIZE_LOG)<<"returning empty KFileItem()"<<index.parent().data().toString();
+    qCInfo(LOKALIZE_LOG)<<"returning empty KFileItem()"<<index.internalPointer();
+    qCInfo(LOKALIZE_LOG)<<"returning empty KFileItem()"<<static_cast<ProjectNode*>(index.internalPointer())->untranslated<<static_cast<ProjectNode*>(index.internalPointer())->sourceDate;
     return KFileItem();
 }
 
@@ -882,7 +886,7 @@ QModelIndex ProjectModel::poOrPotIndexForOuter(const QModelIndex& outerIndex) co
     QModelIndex potIndex = potIndexForOuter(outerIndex);
 
     if (!potIndex.isValid())
-        qWarning()<<"error mapping index to PO or POT";
+        qCWarning(LOKALIZE_LOG)<<"error mapping index to PO or POT";
 
     return potIndex;
 }
@@ -915,7 +919,7 @@ QModelIndex ProjectModel::indexForPotIndex(const QModelIndex& potIndex) const
     if (row != node->rows.count())
         return index(row, potIndex.column(), outerParent);
 
-    qWarning()<<"error mapping index from POT to outer, searched for potRow:"<<potRow;
+    qCWarning(LOKALIZE_LOG)<<"error mapping index from POT to outer, searched for potRow:"<<potRow;
     return QModelIndex();
 }
 
@@ -967,7 +971,7 @@ QUrl ProjectModel::poToPot(const QUrl& poPath) const
 {
     if (!(m_poUrl.isParentOf(poPath)||m_poUrl.matches(poPath, QUrl::StripTrailingSlash)))
     {
-        qWarning()<<"PO path not in project: " << poPath.url();
+        qCWarning(LOKALIZE_LOG)<<"PO path not in project: " << poPath.url();
         return QUrl();
     }
 
@@ -980,7 +984,7 @@ QUrl ProjectModel::poToPot(const QUrl& poPath) const
     QUrl potPath = m_potUrl;
     potPath.setPath(potPath.path()%'/'%pathToAdd);
 
-    //qDebug() << "ProjectModel::poToPot("<< poPath.pathOrUrl() << +") = " << potPath.pathOrUrl();
+    //qCDebug(LOKALIZE_LOG) << "ProjectModel::poToPot("<< poPath.pathOrUrl() << +") = " << potPath.pathOrUrl();
     return potPath;
 }
 
@@ -988,7 +992,7 @@ QUrl ProjectModel::potToPo(const QUrl& potPath) const
 {
     if (!(m_potUrl.isParentOf(potPath)||m_potUrl.matches(potPath, QUrl::StripTrailingSlash)))
     {
-        qWarning()<<"POT path not in project: " << potPath.url();
+        qCWarning(LOKALIZE_LOG)<<"POT path not in project: " << potPath.url();
         return QUrl();
     }
 
@@ -1001,7 +1005,7 @@ QUrl ProjectModel::potToPo(const QUrl& potPath) const
     QUrl poPath = m_poUrl;
     poPath.setPath(poPath.path()%'/'%pathToAdd);
 
-    //qDebug() << "ProjectModel::potToPo("<< potPath.pathOrUrl() << +") = " << poPath.pathOrUrl();
+    //qCDebug(LOKALIZE_LOG) << "ProjectModel::potToPo("<< potPath.pathOrUrl() << +") = " << poPath.pathOrUrl();
     return poPath;
 }
 
@@ -1153,7 +1157,7 @@ void ProjectModel::setMetadataForDir(ProjectNode* node, const QList<FileMetaData
     if (dataCount != rowsCount)
     {
         m_delayedReloadTimer->start(2000);
-        qWarning()<<"dataCount != rowsCount, scheduling full refresh";
+        qCWarning(LOKALIZE_LOG)<<"dataCount != rowsCount, scheduling full refresh";
         return;
     }
 
@@ -1184,7 +1188,7 @@ void ProjectModel::updateDirStats(ProjectNode* node)
     if (node->parent->rows.count()==0 || node->parent->rows.count()>=node->rowNumber)
         return;
     QModelIndex index = indexForNode(node);
-    qWarning()<<index.row()<<node->parent->rows.count();
+    qCDebug(LOKALIZE_LOG)<<index.row()<<node->parent->rows.count();
     if (index.row()>=node->parent->rows.count())
         return;
     QModelIndex topLeft = index.sibling(index.row(), Graph);
@@ -1385,7 +1389,7 @@ static FileMetaData cachedMetaData(const KFileItem& file)
     {
         QSqlDatabase db=QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"),dbName);
         db.setDatabaseName(QStandardPaths::writableLocation(QStandardPaths::DataLocation) % QLatin1Char('/') % dbName % QLatin1String(".sqlite"));
-        if (KDE_ISUNLIKELY( !db.open() ))
+        if (Q_UNLIKELY( !db.open() ))
             return metaData(file.localPath());
         initDataBase(db);
     }
@@ -1425,8 +1429,8 @@ static FileMetaData cachedMetaData(const KFileItem& file)
     query.bindValue(0, qHash(file.localPath()));
     query.bindValue(1, result);
     query.bindValue(2, file.time(KFileItem::ModificationTime));
-    if (KDE_ISUNLIKELY(!query.exec()))
-        qWarning() <<"metainfo cache acquiring error: " <<query.lastError().text();
+    if (Q_UNLIKELY(!query.exec()))
+        qCWarning(LOKALIZE_LOG) <<"metainfo cache acquiring error: " <<query.lastError().text();
 
     return m;
 #endif
