@@ -23,6 +23,8 @@
 
 #include "projectwidget.h"
 
+#include "lokalize_debug.h"
+
 #include "project.h"
 #include "catalog.h"
 #include "headerviewmenu.h"
@@ -31,9 +33,7 @@
 #include <kstringhandler.h>
 #include <kdirsortfilterproxymodel.h>
 #include <kcolorscheme.h>
-#include <kdemacros.h>
 
-#include <QDebug>
 #include <QTreeView>
 #include <QTimer>
 #include <QMouseEvent>
@@ -45,8 +45,6 @@
 #include <QStyledItemDelegate>
 #include <QCollator>
 
-#undef KDE_NO_DEBUG_OUTPUT
-
 
 class PoItemDelegate: public QStyledItemDelegate
 {
@@ -83,7 +81,7 @@ void PoItemDelegate::paint (QPainter *painter, const QStyleOptionViewItem &optio
         return QStyledItemDelegate::paint(painter,option,index);
 
     QVariant graphData = index.data(Qt::DisplayRole);
-    if (KDE_ISUNLIKELY( !graphData.isValid()))
+    if (Q_UNLIKELY( !graphData.isValid()))
     {
         painter->fillRect(option.rect,Qt::transparent);
         return;
@@ -175,7 +173,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
                                         const QModelIndex& right) const
 {
     static QCollator collator;
-//     qWarning()<<right.column()<<"--"<<left.row()<<right.row()<<left.internalPointer()<<right.internalPointer()<<left.parent().isValid()<<right.parent().isValid();
+//     qCWarning(LOKALIZE_LOG)<<right.column()<<"--"<<left.row()<<right.row()<<left.internalPointer()<<right.internalPointer()<<left.parent().isValid()<<right.parent().isValid();
     //<<left.data().toString()<<right.data().toString()
     ProjectModel* projectModel = static_cast<ProjectModel*>(sourceModel());
     const KFileItem leftFileItem  = projectModel->itemForIndex(left);
@@ -192,7 +190,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
 
     if (leftFileItem.isNull() || rightFileItem.isNull())
     {
-        qWarning()<<".isNull()";
+        qCWarning(LOKALIZE_LOG)<<".isNull()";
         return false;
     }
 
@@ -263,6 +261,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
     case ProjectModel::TotalCount:
     case ProjectModel::TranslatedCount:
     case ProjectModel::UntranslatedCount:
+    case ProjectModel::IncompleteCount:
     case ProjectModel::FuzzyCount:
         return projectModel->data(left).toInt() < projectModel->data(right).toInt();
     default:
